@@ -2,7 +2,7 @@
  *
  *  oFono - Open Source Telephony
  *
- *  Copyright (C) 2008-2009  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2008-2010  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -31,13 +31,15 @@
 
 #include <ofono/types.h>
 #include "common.h"
+#include "util.h"
 
 struct error_entry {
 	int error;
 	const char *str;
 };
 
-/* 0-127 from 24.011 Annex E2
+/*
+ * 0-127 from 24.011 Annex E2
  * 127-255 23.040 Section 9.2.3.22
  * Rest are from 27.005 Section 3.2.5
  */
@@ -273,7 +275,7 @@ const char *telephony_error_to_str(const struct ofono_error *error)
 		break;
 	case OFONO_ERROR_TYPE_CMS:
 		e = cms_errors;
-		maxentries = sizeof(cme_errors) / sizeof(struct error_entry);
+		maxentries = sizeof(cms_errors) / sizeof(struct error_entry);
 		break;
 	case OFONO_ERROR_TYPE_CEER:
 		e = ceer_errors;
@@ -294,7 +296,8 @@ int mmi_service_code_to_bearer_class(int code)
 {
 	int cls = 0;
 
-	/* Teleservices according to 22.004
+	/*
+	 * Teleservices according to 22.004
 	 * 1 - Voice
 	 * 2 - SMS
 	 * 3,4,5 - Unallocated
@@ -397,7 +400,8 @@ int valid_ussd_string(const char *str)
 	if (!len)
 		return FALSE;
 
-	/* It is hard to understand exactly what constitutes a valid USSD string
+	/*
+	 * It is hard to understand exactly what constitutes a valid USSD string
 	 * According to 22.090:
 	 * Case a - 1, 2 or 3 digits from the set (*, #) followed by 1X(Y),
 	 * where X=any number 0‑4, Y=any number 0‑9, then, optionally "*
@@ -459,7 +463,8 @@ const char *ss_control_type_to_string(enum ss_control_type type)
 		}				\
 	} while (0)				\
 
-/* Note: The str will be modified, so in case of error you should
+/*
+ * Note: The str will be modified, so in case of error you should
  * throw it away and start over
  */
 gboolean parse_ss_control_string(char *str, int *ss_type,
@@ -518,7 +523,8 @@ gboolean parse_ss_control_string(char *str, int *ss_type,
 
 	NEXT_FIELD(c, *sc);
 
-	/* According to 22.030 SC is 2 or 3 digits, there can be
+	/*
+	 * According to 22.030 SC is 2 or 3 digits, there can be
 	 * an optional digit 'n' if this is a call setup string,
 	 * however 22.030 does not define any SC of length 3
 	 * with an 'n' present
@@ -580,7 +586,7 @@ const char *bearer_class_to_string(enum bearer_class cls)
 	return NULL;
 }
 
-gboolean is_valid_pin(const char *pin)
+gboolean is_valid_pin(const char *pin, enum pin_type type)
 {
 	unsigned int i;
 
@@ -588,14 +594,33 @@ gboolean is_valid_pin(const char *pin)
 	if (pin == NULL || pin[0] == '\0')
 		return FALSE;
 
-	for (i = 0; i < strlen(pin); i++)
-		if (pin[i] < '0' || pin[i] > '9')
-			return FALSE;
-
-	if (i > 8)
+	i = strlen(pin);
+	if (i != strspn(pin, "0123456789"))
 		return FALSE;
 
-	return TRUE;
+	switch (type) {
+	case PIN_TYPE_PIN:
+		/* 11.11 Section 9.3 ("CHV"): 4..8 IA-5 digits */
+		if (4 <= i && i <= 8)
+			return TRUE;
+		break;
+	case PIN_TYPE_PUK:
+		/* 11.11 Section 9.3 ("UNBLOCK CHV"), 8 IA-5 digits */
+		if (i == 8)
+			return TRUE;
+		break;
+	case PIN_TYPE_NET:
+		/* 22.004 Section 5.2, 4 IA-5 digits */
+		if (i == 4)
+			return TRUE;
+		break;
+	case PIN_TYPE_NONE:
+		if (i < 8)
+			return TRUE;
+		break;
+	}
+
+	return FALSE;
 }
 
 const char *registration_status_to_string(int status)
@@ -622,22 +647,55 @@ const char *registration_tech_to_string(int tech)
 {
 	switch (tech) {
 	case ACCESS_TECHNOLOGY_GSM:
-		return "GSM";
+		return "gsm";
 	case ACCESS_TECHNOLOGY_GSM_COMPACT:
-		return "GSMCompact";
+		return "gsm";
 	case ACCESS_TECHNOLOGY_UTRAN:
-		return "UTRAN";
+		return "umts";
 	case ACCESS_TECHNOLOGY_GSM_EGPRS:
-		return "GSM+EGPRS";
+		return "edge";
 	case ACCESS_TECHNOLOGY_UTRAN_HSDPA:
-		return "UTRAN+HSDPA";
+		return "hspa";
 	case ACCESS_TECHNOLOGY_UTRAN_HSUPA:
-		return "UTRAN+HSUPA";
+		return "hspa";
 	case ACCESS_TECHNOLOGY_UTRAN_HSDPA_HSUPA:
-		return "UTRAN+HSDPA+HSUPA";
+		return "hspa";
 	case ACCESS_TECHNOLOGY_EUTRAN:
-		return "EUTRAN";
+		return "lte";
 	default:
 		return "";
 	}
 }
+
+gboolean is_valid_apn(const char *apn)
+{
+	int i;
+	int last_period = 0;
+
+	if (apn[0] == '.' || apn[0] == '\0')
+		return FALSE;
+
+	for (i = 0; apn[i] != '\0'; i++) {
+		if (g_ascii_isalnum(apn[i]))
+			continue;
+
+		if (apn[i] == '-')
+			continue;
+
+		if (apn[i] == '.' && (i - last_period) > 1) {
+			last_period = i;
+			continue;
+		}
+
+		return FALSE;
+	}
+
+	return TRUE;
+}
+
+const char *ofono_uuid_to_str(const struct ofono_uuid *uuid)
+{
+	static char buf[OFONO_SHA1_UUID_LEN * 2 + 1];
+
+	return encode_hex_own_buf(uuid->uuid, OFONO_SHA1_UUID_LEN, 0, buf);
+}
